import { Component, Injectable } from '@angular/core';
import { Http, Response, Headers, RequestOptions } from '@angular/http';
import 'rxjs/add/operator/map';
import { Observable } from 'rxjs/Observable';

declare var jQuery: any;

@Injectable()
export class ProductService {
    constructor(private http: Http) { }

    getAll() {
        let people$ = this.http
            .get("app/products").map((res: Response) => res.json());
        return people$;
    }

    addProduct(ProductID, ProductName, DealerName, CategoryName, InStock): Observable<any> {
        let body = JSON.stringify({ ProductID, ProductName, DealerName, CategoryName, InStock });
        let headers = new Headers({ 'Content-Type': 'application/json' });
        let options = new RequestOptions({ headers: headers });

        return this.http.post("app/products", body, options)
            .map(this.extractData);
    }


    private extractData(res: Response) {
        let body = res.json();
        return body.data || {};
    }

    private handleError(error: any) {
        let errMsg = (error.message) ? error.message :
            error.status ? `${error.status} - ${error.statusText}` : 'Server error';
        console.error(errMsg); // log to console instead
        return Observable.throw(errMsg);
    }
}

@Component({
    selector: 'my-app',
    template: `
		<ig-tree [options]="treeOpts" [(dataSource)]="products" [(widgetId)]='id'></ig-tree>
		`,
    providers: [ProductService]
})
export class AppComponent {
    public id: string;
    public products: any = [];
    public treeOpts: IgTree;
    public errorMessage: string;

    constructor(private productService: ProductService) {
        this.productService.getAll().subscribe(
            res => {
                this.products = res.data;
            },
            error => this.errorMessage = <any>error
        );

        this.id = 'tree1';

        this.treeOpts = {
            bindings: {
                childDataProperty: "ProductSubcategories",
                textKey: "Name",
                valueKey: "ProductCategoryID"
            }
        };
    }
}
